@@ -11,7 +11,7 @@ use Mojo::ACME::CA;
 
 my %authorities = (
   letsencrypt => {
-    agreement => 'https://letsencrypt.org/documents/LE-SA-v1.0.1-July-27-2015.pdf',
+    agreement => 'https://letsencrypt.org/documents/LE-SA-v1.1.1-August-1-2016.pdf',
     name => q[Let's Encrypt],
     intermediate => 'https://letsencrypt.org/certs/lets-encrypt-x3-cross-signed.pem',
     primary_url => Mojo::URL->new('https://acme-v01.api.letsencrypt.org'),
